API Reference
=============

This section provides comprehensive API documentation for all OpenFire modules, organized by source document.

.. toctree::
   :maxdepth: 2

   br-187
   bs-9999
   cibse-guide-e
   eurocode-1-1-2
   fire-dynamics-tools
   introduction-to-fire-dynamics
   pd-7974
   sfpe-handbook
   tr-17

Core Module
-----------

.. automodule:: ofire
   :members:
   :undoc-members:
   :show-inheritance: